@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
-__copyright__ = "(C) 2006-2008 Ola Skavhaug and Simula Research Laboratory"
+__copyright__ = "(C) 2006-2009 Ola Skavhaug and Simula Research Laboratory"
 __license__   = "GNU LGPL Version 2.1."
 __cite__      = """Ola Skavhaug, Viper Visualization Software, 
 http://www.fenics.org/wiki/viper/"""
-__version__ = "0.4.3"
+__version__ = "0.4.5"
 
 r"""
 Viper
@@ -72,7 +72,7 @@ __init__(..., cutplane_origin = origin, cutplane_normal = normal)
 
 Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         """
-        if len(kwargs) == 0:
+        if len(args) > 0:
             nargs = len(args)
             if not nargs > 0:
                 raise RuntimeError, "No arguments to Viper, giving up"
@@ -288,7 +288,6 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
         self.title = kwargs.get("title", "FEniCS Viper")
         self.rescale = kwargs.get("rescale", False)
         self.lutfile = kwargs.get("lutfile", "gauss_120.lut")
-        self.title = kwargs.get("title", "FEniCS Viper")
         self.frame = kwargs.get("frame", None)
         self.axes_on = kwargs.get("axes", False)
         self.window_size = kwargs.get("size", (600, 400))
@@ -586,11 +585,15 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
 
         cl[:,:_cl.shape[1]] = _cl
 
-        inttype = nl.dtype
+        VTK_ID_TYPE_SIZE = vtk.vtkIdTypeArray().GetDataTypeSize()
+        if VTK_ID_TYPE_SIZE == 4:
+            inttype = numpy.int32
+        elif VTK_ID_TYPE_SIZE == 8:
+            inttype = numpy.int64
         
         # Create a cell array, stored in Python.numpy
         ncells = len(nl)
-        cells = numpy.zeros((ncells, cellsize),dtype=inttype)
+        cells = numpy.zeros((ncells, cellsize), dtype=inttype)
         
         cells[:,1:cellsize] = nl
         cells[:,0] = cellsize - 1 
@@ -794,7 +797,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
             renWin = vtk.vtkRenderWindow()
             renWin.SetWindowName(self.title)
             renWin.AddRenderer(ren)
-            renWin.SetSize(self.window_size)
+            renWin.SetSize(*self.window_size)
         return ren, renWin
 
     def compute_vector_scale(self, x, scale=2.0):
